@@ -51,7 +51,7 @@
 #include "../vtls/vtls.h"
 
 /* HTTP/3 error values defined in RFC 9114, ch. 8.1 */
-#define CURL_H3_NO_ERROR  (0x0100)
+#define CURL_H3_NO_ERROR  0x0100
 
 #define QUIC_MAX_STREAMS              (100)
 
@@ -1082,7 +1082,7 @@ static CURLcode h3_open_stream(struct Curl_cfilter *cf,
     CURLcode r2 = CURLE_OK;
 
     r2 = cf_quiche_send_body(cf, data, stream, buf, blen, eos, &nwritten);
-    if(r2 && (CURLE_AGAIN != r2)) {  /* real error, fail */
+    if(r2 && (r2 != CURLE_AGAIN)) {  /* real error, fail */
       result = r2;
     }
     else if(nwritten > 0) {
